@@ -1,6 +1,6 @@
 package Pod::Weaver::Section::Contributors;
 {
-  $Pod::Weaver::Section::Contributors::VERSION = '0.002';
+  $Pod::Weaver::Section::Contributors::VERSION = '0.003';
 }
 use Moose;
 with 'Pod::Weaver::Role::Section';
@@ -12,8 +12,18 @@ use Pod::Elemental::Element::Nested;
 use Pod::Elemental::Element::Pod5::Verbatim;
 
 
+
+has head => (
+    is      => 'rw',
+    isa     => 'Int',
+    lazy    => 1,
+    default => 1,
+);
+
+
 sub mvp_multivalue_args { qw( contributors ) }
 
+
 has contributors => (
     is      => 'ro',
     isa     => 'ArrayRef[Str]',
@@ -39,7 +49,7 @@ sub weave_section {
         my ($config, $contri);
         $config = $stash->get_stashed_config($self) if $stash;
         $contri = $config->{contributors}           if $config;
-        push (@contributors, @{$contri})         if $contri;
+        push (@contributors, @{$contri})            if $contri;
     }
 
     ## 4 - get contributors from source comments
@@ -82,14 +92,27 @@ sub weave_section {
         }),
     ] if $multiple_contributors;
 
-    $document->children->push(
-        Pod::Elemental::Element::Nested->new({
-            type     => 'command',
-            command  => 'head1',
-            content  => $name,
-            children => $result,
-        }),
-    );
+    ## Check if head is found on the stash
+    if ( $input->{zilla} ) {
+        my $stash  = $input->{zilla}->stash_named('%PodWeaver');
+        my $config = $stash->get_stashed_config($self) if $stash;
+
+        $self->head($config->{head}) if defined $config && defined $config->{head};
+    }
+
+    if ( $self->head ) {
+        $document->children->push(
+            Pod::Elemental::Element::Nested->new({
+                type     => 'command',
+                command  => 'head' . $self->head,
+                content  => $name,
+                children => $result,
+            }),
+        );
+    }
+    else {
+        $document->children->push($_) for @$result;
+    }
 }
 
 no Moose;
@@ -107,7 +130,7 @@ Pod::Weaver::Section::Contributors - a section listing contributors
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -115,12 +138,14 @@ on dist.ini:
 
     [PodWeaver]
     [%PodWeaver]
+    Contributors.head = 2
     Contributors.contributors[0] = keedi - Keedi Kim - 김도형 (cpan: KEEDI) <keedi@cpan.org>
     Contributors.contributors[1] = carandraug - Carnë Draug (cpan: CDRAUG) <cdraug@cpan.org>
 
 and/or weaver.ini:
 
     [Contributors]
+    head = 2
     contributors = keedi - Keedi Kim - 김도형 (cpan: KEEDI) <keedi@cpan.org>
     contributors = carandraug - Carnë Draug (cpan: CDRAUG) <cdraug@cpan.org>
 
@@ -144,21 +169,66 @@ To support distributions with multiple modules, it is also able to derive a list
 of contributors in a file basis by looking at comments on each module. Names of
 contributors on the source, will only appear on the POD of those modules.
 
+=head1 ATTRIBUTES
+
+=head2 head
+
+The heading level of this section.  If 0, it inserts an ordinary piece of text
+with no heading. Defaults to 1.
+
+In case the value is passed both to Pod::Weaver and to the Pod::Weaver stash,
+it uses the value found in the stash.
+
+=head2 contributors
+
+The list of contributors.
+
+In case the value is passed to C<weave_section()>, to Pod::Weaver
+and to the Pod::Weaver stash, it merges all contributors.
+
 =for Pod::Coverage mvp_multivalue_args
 
 =for Pod::Coverage weave_section
 
 =head1 SEE ALSO
 
-=over
+=over 4
 
-=item L<Dist::Zilla>
+=item *
 
-=item L<Dist::Zilla::Role::Stash::Plugins>
+L<dagolden's 'How I'm using Dist::Zilla to give credit to contributors'|http://www.dagolden.com/index.php/1921/how-im-using-distzilla-to-give-credit-to-contributors/>
 
-=item L<Pod::Weaver>
+=item *
 
-=item L<Pod::Weaver::Section::Authors>
+L<Dist::Zilla::Plugin::ContributorsFromGit>
+
+=item *
+
+L<Dist::Zilla::Stash::Contributors>
+
+=item *
+
+L<Dist::Zilla::Plugin::Meta::Contributors>
+
+=item *
+
+L<Dist::Zilla::Plugin::ContributorsFile>
+
+=item *
+
+L<Dist::Zilla>
+
+=item *
+
+L<Dist::Zilla::Role::Stash::Plugins>
+
+=item *
+
+L<Pod::Weaver>
+
+=item *
+
+L<Pod::Weaver::Section::Authors>
 
 =back
 
@@ -166,10 +236,20 @@ contributors on the source, will only appear on the POD of those modules.
 
 Keedi Kim - 김도형 <keedi@cpan.org>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
 
 carandraug - Carnë Draug (cpan: CDRAUG) <cdraug@cpan.org>
 
+=item *
+
+ether - Karen Etheridge (cpan: ETHER) <ether@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by Keedi Kim.
